#!/usr/bin/python

#
# Simple, naive bibtex parser
#
# Vassilios Karakoidas (2008) - vassilios.karakoidas@gmail.com
#

# bib categories
#
# @Article{
# @Book{
# @Booklet{
# @InBook{
# @InCollection{
# @InProceedings{
# @Manual{
# @MastersThesis{
# @Misc{
# @PhDThesis{
# @Proceedings{
# @TechReport{
# @Unpublished{
#

import re
import os

from cStringIO import StringIO

class BibtexEntry:
	def __init__(self, bibfile):
		self.key = ''
		self.data = {}
		self.btype = ''
		self.data['filename'] = bibfile		

	def getKey(self, key):		
		if(key.lower().strip() == self.key.lower()):
			return True

		return False

	def search(self, keywords):
		for word in keywords:
			for (k, v) in self.data.iteritems():
				try:
					v.lower().index(word.lower())
					return True
				except ValueError:
					continue

		return False
	
	def __get_pdf_name(self):
		if len(self.key) == 0:
			return None
		
		m = re.match('(.+/[^.]+)\\.bib', self.data['filename'])		
		if m == None:
			return None
		
		filename = "%s/%s.pdf" % ( m.group(1).strip(), self.key.lower() )
		if os.access(filename, os.O_RDONLY) == 1:
			return filename
		
		return None		
	
	def has_pdf(self):
		return (self.__get_pdf_name() != None)

	def export(self):
		return self.__str__()
		
	def totext(self):
		return
		
	def tohtml(self):
		return

	def __str__(self):
		result = StringIO()

		result.write("@%s{%s,\n" % ( self.btype.lower().strip(), self.key.strip() ))

		for k, v in self.data.iteritems():
			result.write("\t%s = {%s},\n" % ( k.title().strip(), v.strip() ))
		
		filename =  self.__get_pdf_name()
		if filename != None:
			result.write("\tpdf-file = {%s},\n" % ( filename, ))

		result.write('}\n')

		return result.getvalue()

def parse_bib(bibfile):
	bibitems = []
	bib_file = open(bibfile, "r")

	re_head = re.compile('@([a-zA-Z]+)[ ]*\{[ ]*(.*),')
	current = None

	for l in bib_file:
		mr = re_head.match(l.strip())
		if mr != None:
			if current == None:
				current = BibtexEntry(bibfile)
			else:
				bibitems.append(current)
				current = BibtexEntry(bibfile)
			current.key = mr.group(2).strip()
			current.btype = mr.group(1).strip()
			continue
		try:
			l.index('=')
			kv_data = l.split('=')
			key = kv_data[0].strip().lower()
			mr = re.search('["{](.+)["}]',kv_data[1].strip())
			if mr != None:
				value = mr.group(1).strip()
				value = value.replace("{", "")
				value = value.replace("}", "")
				current.data[key] = value
		except (ValueError, AttributeError):
			continue

	bibitems.append(current)
	bib_file.close()

	return bibitems



import os
from setuptools import setup


setup(
    name = "bib2coins",
    packages = ['bibtex'],
    py_modules = ['bib2coins'],
    scripts = ['bib2coins'],
    version = "0.1",
    author = "Robin Wilson",
    author_email = "robin@rtwilson.com",
    description = ("""Module to parse human-style date ranges (eg. 15th-19th March 2011) to datetimes"""),
    license = "BSD",
    url = "https://github.com/robintw/bib2coins",
    long_description="""bib2coins is a simple tool which will convert BibTeX files to COINS metadata (see http://ocoins.info/) ready for inclusion in a webpage. You may want to use this is you have a BibTeX file of your own publications and you display a list of these publications on a webpage. bib2coins can be used to convert the BibTeX files to a set of <span> elements which can be included in your HTML file to allow bibliographic software (such as Mendeley and Zotero) to automatically pick up the metadata from the page and allow the papers on the page to be easily added to the software's database.

    See https://github.com/robintw/bib2coins for more details""",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Science/Research",
        "Topic :: Text Editors :: Text Processing",
        "Topic :: Text Processing :: Markup :: LaTeX",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python"
        
    ],
)